# -*- coding: utf-8 -*-
#
# Copyright (c) ZeroC, Inc. All rights reserved.
#
#
# Ice version 3.7.8
#
# <auto-generated>
#
# Generated from file `SliceChecksumDict.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy

# Start of module Ice
_M_Ice = Ice.openModule('Ice')
__name__ = 'Ice'

if '_t_SliceChecksumDict' not in _M_Ice.__dict__:
    _M_Ice._t_SliceChecksumDict = IcePy.defineDictionary('::Ice::SliceChecksumDict', (), IcePy._t_string, IcePy._t_string)

# End of module Ice

Ice.sliceChecksums["::Ice::SliceChecksumDict"] = "d733c49f2c6d79a346ca7d695f0519"



# -*- coding: utf-8 -*-
#
# Copyright (c) ZeroC, Inc. All rights reserved.
#
#
# Ice version 3.7.8
#
# <auto-generated>
#
# Generated from file `Properties.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import Ice.PropertiesAdmin_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Start of module Ice
__name__ = 'Ice'

if 'Properties' not in _M_Ice.__dict__:
    _M_Ice.Properties = Ice.createTempClass()
    class Properties(object):
        """
        A property set used to configure Ice and Ice applications.
        Properties are key/value pairs, with both keys and values
        being strings. By convention, property keys should have the form
        application-name\[.category\[.sub-category]].name.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Ice.Properties:
                raise RuntimeError('Ice.Properties is an abstract class')

        def getProperty(self, key):
            """
            Get a property by key. If the property is not set, an empty
            string is returned.
            Arguments:
            key -- The property key.
            Returns: The property value.
            """
            raise NotImplementedError("method 'getProperty' not implemented")

        def getPropertyWithDefault(self, key, value):
            """
            Get a property by key. If the property is not set, the
            given default value is returned.
            Arguments:
            key -- The property key.
            value -- The default value to use if the property does not exist.
            Returns: The property value or the default value.
            """
            raise NotImplementedError("method 'getPropertyWithDefault' not implemented")

        def getPropertyAsInt(self, key):
            """
            Get a property as an integer. If the property is not set, 0
            is returned.
            Arguments:
            key -- The property key.
            Returns: The property value interpreted as an integer.
            """
            raise NotImplementedError("method 'getPropertyAsInt' not implemented")

        def getPropertyAsIntWithDefault(self, key, value):
            """
            Get a property as an integer. If the property is not set, the
            given default value is returned.
            Arguments:
            key -- The property key.
            value -- The default value to use if the property does not exist.
            Returns: The property value interpreted as an integer, or the default value.
            """
            raise NotImplementedError("method 'getPropertyAsIntWithDefault' not implemented")

        def getPropertyAsList(self, key):
            """
            Get a property as a list of strings. The strings must be
            separated by whitespace or comma. If the property is not set,
            an empty list is returned. The strings in the list can contain
            whitespace and commas if they are enclosed in single or double
            quotes. If quotes are mismatched, an empty list is returned.
            Within single quotes or double quotes, you can escape the
            quote in question with \, e.g. O'Reilly can be written as
            O'Reilly, "O'Reilly" or 'O\'Reilly'.
            Arguments:
            key -- The property key.
            Returns: The property value interpreted as a list of strings.
            """
            raise NotImplementedError("method 'getPropertyAsList' not implemented")

        def getPropertyAsListWithDefault(self, key, value):
            """
            Get a property as a list of strings.  The strings must be
            separated by whitespace or comma. If the property is not set,
            the default list is returned. The strings in the list can contain
            whitespace and commas if they are enclosed in single or double
            quotes. If quotes are mismatched, the default list is returned.
            Within single quotes or double quotes, you can escape the
            quote in question with \, e.g. O'Reilly can be written as
            O'Reilly, "O'Reilly" or 'O\'Reilly'.
            Arguments:
            key -- The property key.
            value -- The default value to use if the property is not set.
            Returns: The property value interpreted as list of strings, or the default value.
            """
            raise NotImplementedError("method 'getPropertyAsListWithDefault' not implemented")

        def getPropertiesForPrefix(self, prefix):
            """
            Get all properties whose keys begins with
            prefix. If
            prefix is an empty string,
            then all properties are returned.
            Arguments:
            prefix -- The prefix to search for (empty string if none).
            Returns: The matching property set.
            """
            raise NotImplementedError("method 'getPropertiesForPrefix' not implemented")

        def setProperty(self, key, value):
            """
            Set a property. To unset a property, set it to
            the empty string.
            Arguments:
            key -- The property key.
            value -- The property value.
            """
            raise NotImplementedError("method 'setProperty' not implemented")

        def getCommandLineOptions(self):
            """
            Get a sequence of command-line options that is equivalent to
            this property set. Each element of the returned sequence is
            a command-line option of the form
            --key=value.
            Returns: The command line options for this property set.
            """
            raise NotImplementedError("method 'getCommandLineOptions' not implemented")

        def parseCommandLineOptions(self, prefix, options):
            """
            Convert a sequence of command-line options into properties.
            All options that begin with
            --prefix. are
            converted into properties. If the prefix is empty, all options
            that begin with -- are converted to properties.
            Arguments:
            prefix -- The property prefix, or an empty string to convert all options starting with --.
            options -- The command-line options.
            Returns: The command-line options that do not start with the specified prefix, in their original order.
            """
            raise NotImplementedError("method 'parseCommandLineOptions' not implemented")

        def parseIceCommandLineOptions(self, options):
            """
            Convert a sequence of command-line options into properties.
            All options that begin with one of the following prefixes
            are converted into properties: --Ice, --IceBox, --IceGrid,
            --IcePatch2, --IceSSL, --IceStorm, --Freeze, and --Glacier2.
            Arguments:
            options -- The command-line options.
            Returns: The command-line options that do not start with one of the listed prefixes, in their original order.
            """
            raise NotImplementedError("method 'parseIceCommandLineOptions' not implemented")

        def load(self, file):
            """
            Load properties from a file.
            Arguments:
            file -- The property file.
            """
            raise NotImplementedError("method 'load' not implemented")

        def clone(self):
            """
            Create a copy of this property set.
            Returns: A copy of this property set.
            """
            raise NotImplementedError("method 'clone' not implemented")

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_Properties)

        __repr__ = __str__

    _M_Ice._t_Properties = IcePy.defineValue('::Ice::Properties', Properties, -1, (), False, True, None, ())
    Properties._ice_type = _M_Ice._t_Properties

    _M_Ice.Properties = Properties
    del Properties

# End of module Ice



# -*- coding: utf-8 -*-
#
# Copyright (c) ZeroC, Inc. All rights reserved.
#
#
# Ice version 3.7.8
#
# <auto-generated>
#
# Generated from file `Registry.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import IceGrid.Exception_ice
import IceGrid.Session_ice
import IceGrid.Admin_ice
import Ice.Locator_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module IceGrid
_M_IceGrid = Ice.openModule('IceGrid')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Start of module IceGrid
__name__ = 'IceGrid'

if 'LoadSample' not in _M_IceGrid.__dict__:
    _M_IceGrid.LoadSample = Ice.createTempClass()
    class LoadSample(Ice.EnumBase):
        """
        Determines which load sampling interval to use.
        Enumerators:
        LoadSample1 -- Sample every minute.
        LoadSample5 -- Sample every five minutes.
        LoadSample15 -- Sample every fifteen minutes.
        """

        def __init__(self, _n, _v):
            Ice.EnumBase.__init__(self, _n, _v)

        def valueOf(self, _n):
            if _n in self._enumerators:
                return self._enumerators[_n]
            return None
        valueOf = classmethod(valueOf)

    LoadSample.LoadSample1 = LoadSample("LoadSample1", 0)
    LoadSample.LoadSample5 = LoadSample("LoadSample5", 1)
    LoadSample.LoadSample15 = LoadSample("LoadSample15", 2)
    LoadSample._enumerators = { 0:LoadSample.LoadSample1, 1:LoadSample.LoadSample5, 2:LoadSample.LoadSample15 }

    _M_IceGrid._t_LoadSample = IcePy.defineEnum('::IceGrid::LoadSample', LoadSample, (), LoadSample._enumerators)

    _M_IceGrid.LoadSample = LoadSample
    del LoadSample

_M_IceGrid._t_Query = IcePy.defineValue('::IceGrid::Query', Ice.Value, -1, (), False, True, None, ())

if 'QueryPrx' not in _M_IceGrid.__dict__:
    _M_IceGrid.QueryPrx = Ice.createTempClass()
    class QueryPrx(Ice.ObjectPrx):

        """
        Find a well-known object by identity.
        Arguments:
        id -- The identity.
        context -- The request context for the invocation.
        Returns: The proxy or null if no such object has been found.
        """
        def findObjectById(self, id, context=None):
            return _M_IceGrid.Query._op_findObjectById.invoke(self, ((id, ), context))

        """
        Find a well-known object by identity.
        Arguments:
        id -- The identity.
        context -- The request context for the invocation.
        Returns: A future object for the invocation.
        """
        def findObjectByIdAsync(self, id, context=None):
            return _M_IceGrid.Query._op_findObjectById.invokeAsync(self, ((id, ), context))

        """
        Find a well-known object by identity.
        Arguments:
        id -- The identity.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        context -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_findObjectById(self, id, _response=None, _ex=None, _sent=None, context=None):
            return _M_IceGrid.Query._op_findObjectById.begin(self, ((id, ), _response, _ex, _sent, context))

        """
        Find a well-known object by identity.
        Arguments:
        id -- The identity.
        Returns: The proxy or null if no such object has been found.
        """
        def end_findObjectById(self, _r):
            return _M_IceGrid.Query._op_findObjectById.end(self, _r)

        """
        Find a well-known object by type. If there are several objects
        registered for the given type, the object is randomly
        selected.
        Arguments:
        type -- The object type.
        context -- The request context for the invocation.
        Returns: The proxy or null, if no such object has been found.
        """
        def findObjectByType(self, type, context=None):
            return _M_IceGrid.Query._op_findObjectByType.invoke(self, ((type, ), context))

        """
        Find a well-known object by type. If there are several objects
        registered for the given type, the object is randomly
        selected.
        Arguments:
        type -- The object type.
        context -- The request context for the invocation.
        Returns: A future object for the invocation.
        """
        def findObjectByTypeAsync(self, type, context=None):
            return _M_IceGrid.Query._op_findObjectByType.invokeAsync(self, ((type, ), context))

        """
        Find a well-known object by type. If there are several objects
        registered for the given type, the object is randomly
        selected.
        Arguments:
        type -- The object type.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        context -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_findObjectByType(self, type, _response=None, _ex=None, _sent=None, context=None):
            return _M_IceGrid.Query._op_findObjectByType.begin(self, ((type, ), _response, _ex, _sent, context))

        """
        Find a well-known object by type. If there are several objects
        registered for the given type, the object is randomly
        selected.
        Arguments:
        type -- The object type.
        Returns: The proxy or null, if no such object has been found.
        """
        def end_findObjectByType(self, _r):
            return _M_IceGrid.Query._op_findObjectByType.end(self, _r)

        """
        Find a well-known object by type on the least-loaded node. If
        the registry does not know which node hosts the object
        (for example, because the object was registered with a direct proxy), the
        registry assumes the object is hosted on a node that has a load
        average of 1.0.
        Arguments:
        type -- The object type.
        sample -- The sampling interval.
        context -- The request context for the invocation.
        Returns: The proxy or null, if no such object has been found.
        """
        def findObjectByTypeOnLeastLoadedNode(self, type, sample, context=None):
            return _M_IceGrid.Query._op_findObjectByTypeOnLeastLoadedNode.invoke(self, ((type, sample), context))

        """
        Find a well-known object by type on the least-loaded node. If
        the registry does not know which node hosts the object
        (for example, because the object was registered with a direct proxy), the
        registry assumes the object is hosted on a node that has a load
        average of 1.0.
        Arguments:
        type -- The object type.
        sample -- The sampling interval.
        context -- The request context for the invocation.
        Returns: A future object for the invocation.
        """
        def findObjectByTypeOnLeastLoadedNodeAsync(self, type, sample, context=None):
            return _M_IceGrid.Query._op_findObjectByTypeOnLeastLoadedNode.invokeAsync(self, ((type, sample), context))

        """
        Find a well-known object by type on the least-loaded node. If
        the registry does not know which node hosts the object
        (for example, because the object was registered with a direct proxy), the
        registry assumes the object is hosted on a node that has a load
        average of 1.0.
        Arguments:
        type -- The object type.
        sample -- The sampling interval.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        context -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_findObjectByTypeOnLeastLoadedNode(self, type, sample, _response=None, _ex=None, _sent=None, context=None):
            return _M_IceGrid.Query._op_findObjectByTypeOnLeastLoadedNode.begin(self, ((type, sample), _response, _ex, _sent, context))

        """
        Find a well-known object by type on the least-loaded node. If
        the registry does not know which node hosts the object
        (for example, because the object was registered with a direct proxy), the
        registry assumes the object is hosted on a node that has a load
        average of 1.0.
        Arguments:
        type -- The object type.
        sample -- The sampling interval.
        Returns: The proxy or null, if no such object has been found.
        """
        def end_findObjectByTypeOnLeastLoadedNode(self, _r):
            return _M_IceGrid.Query._op_findObjectByTypeOnLeastLoadedNode.end(self, _r)

        """
        Find all the well-known objects with the given type.
        Arguments:
        type -- The object type.
        context -- The request context for the invocation.
        Returns: The proxies or an empty sequence, if no such objects have been found.
        """
        def findAllObjectsByType(self, type, context=None):
            return _M_IceGrid.Query._op_findAllObjectsByType.invoke(self, ((type, ), context))

        """
        Find all the well-known objects with the given type.
        Arguments:
        type -- The object type.
        context -- The request context for the invocation.
        Returns: A future object for the invocation.
        """
        def findAllObjectsByTypeAsync(self, type, context=None):
            return _M_IceGrid.Query._op_findAllObjectsByType.invokeAsync(self, ((type, ), context))

        """
        Find all the well-known objects with the given type.
        Arguments:
        type -- The object type.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        context -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_findAllObjectsByType(self, type, _response=None, _ex=None, _sent=None, context=None):
            return _M_IceGrid.Query._op_findAllObjectsByType.begin(self, ((type, ), _response, _ex, _sent, context))

        """
        Find all the well-known objects with the given type.
        Arguments:
        type -- The object type.
        Returns: The proxies or an empty sequence, if no such objects have been found.
        """
        def end_findAllObjectsByType(self, _r):
            return _M_IceGrid.Query._op_findAllObjectsByType.end(self, _r)

        """
        Find all the object replicas associated with the given
        proxy. If the given proxy is not an indirect proxy from a
        replica group, an empty sequence is returned.
        Arguments:
        proxy -- The object proxy.
        context -- The request context for the invocation.
        Returns: The proxies of each object replica or an empty sequence, if the given proxy is not from a replica group.
        """
        def findAllReplicas(self, proxy, context=None):
            return _M_IceGrid.Query._op_findAllReplicas.invoke(self, ((proxy, ), context))

        """
        Find all the object replicas associated with the given
        proxy. If the given proxy is not an indirect proxy from a
        replica group, an empty sequence is returned.
        Arguments:
        proxy -- The object proxy.
        context -- The request context for the invocation.
        Returns: A future object for the invocation.
        """
        def findAllReplicasAsync(self, proxy, context=None):
            return _M_IceGrid.Query._op_findAllReplicas.invokeAsync(self, ((proxy, ), context))

        """
        Find all the object replicas associated with the given
        proxy. If the given proxy is not an indirect proxy from a
        replica group, an empty sequence is returned.
        Arguments:
        proxy -- The object proxy.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        context -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_findAllReplicas(self, proxy, _response=None, _ex=None, _sent=None, context=None):
            return _M_IceGrid.Query._op_findAllReplicas.begin(self, ((proxy, ), _response, _ex, _sent, context))

        """
        Find all the object replicas associated with the given
        proxy. If the given proxy is not an indirect proxy from a
        replica group, an empty sequence is returned.
        Arguments:
        proxy -- The object proxy.
        Returns: The proxies of each object replica or an empty sequence, if the given proxy is not from a replica group.
        """
        def end_findAllReplicas(self, _r):
            return _M_IceGrid.Query._op_findAllReplicas.end(self, _r)

        @staticmethod
        def checkedCast(proxy, facetOrContext=None, context=None):
            return _M_IceGrid.QueryPrx.ice_checkedCast(proxy, '::IceGrid::Query', facetOrContext, context)

        @staticmethod
        def uncheckedCast(proxy, facet=None):
            return _M_IceGrid.QueryPrx.ice_uncheckedCast(proxy, facet)

        @staticmethod
        def ice_staticId():
            return '::IceGrid::Query'
    _M_IceGrid._t_QueryPrx = IcePy.defineProxy('::IceGrid::Query', QueryPrx)

    _M_IceGrid.QueryPrx = QueryPrx
    del QueryPrx

    _M_IceGrid.Query = Ice.createTempClass()
    class Query(Ice.Object):

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::IceGrid::Query')

        def ice_id(self, current=None):
            return '::IceGrid::Query'

        @staticmethod
        def ice_staticId():
            return '::IceGrid::Query'

        def findObjectById(self, id, current=None):
            """
            Find a well-known object by identity.
            Arguments:
            id -- The identity.
            current -- The Current object for the invocation.
            Returns: A future object for the invocation.
            """
            raise NotImplementedError("servant method 'findObjectById' not implemented")

        def findObjectByType(self, type, current=None):
            """
            Find a well-known object by type. If there are several objects
            registered for the given type, the object is randomly
            selected.
            Arguments:
            type -- The object type.
            current -- The Current object for the invocation.
            Returns: A future object for the invocation.
            """
            raise NotImplementedError("servant method 'findObjectByType' not implemented")

        def findObjectByTypeOnLeastLoadedNode(self, type, sample, current=None):
            """
            Find a well-known object by type on the least-loaded node. If
            the registry does not know which node hosts the object
            (for example, because the object was registered with a direct proxy), the
            registry assumes the object is hosted on a node that has a load
            average of 1.0.
            Arguments:
            type -- The object type.
            sample -- The sampling interval.
            current -- The Current object for the invocation.
            Returns: A future object for the invocation.
            """
            raise NotImplementedError("servant method 'findObjectByTypeOnLeastLoadedNode' not implemented")

        def findAllObjectsByType(self, type, current=None):
            """
            Find all the well-known objects with the given type.
            Arguments:
            type -- The object type.
            current -- The Current object for the invocation.
            Returns: A future object for the invocation.
            """
            raise NotImplementedError("servant method 'findAllObjectsByType' not implemented")

        def findAllReplicas(self, proxy, current=None):
            """
            Find all the object replicas associated with the given
            proxy. If the given proxy is not an indirect proxy from a
            replica group, an empty sequence is returned.
            Arguments:
            proxy -- The object proxy.
            current -- The Current object for the invocation.
            Returns: A future object for the invocation.
            """
            raise NotImplementedError("servant method 'findAllReplicas' not implemented")

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_QueryDisp)

        __repr__ = __str__

    _M_IceGrid._t_QueryDisp = IcePy.defineClass('::IceGrid::Query', Query, (), None, ())
    Query._ice_type = _M_IceGrid._t_QueryDisp

    Query._op_findObjectById = IcePy.Operation('findObjectById', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (((), _M_Ice._t_Identity, False, 0),), (), ((), IcePy._t_ObjectPrx, False, 0), ())
    Query._op_findObjectByType = IcePy.Operation('findObjectByType', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (((), IcePy._t_string, False, 0),), (), ((), IcePy._t_ObjectPrx, False, 0), ())
    Query._op_findObjectByTypeOnLeastLoadedNode = IcePy.Operation('findObjectByTypeOnLeastLoadedNode', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (((), IcePy._t_string, False, 0), ((), _M_IceGrid._t_LoadSample, False, 0)), (), ((), IcePy._t_ObjectPrx, False, 0), ())
    Query._op_findAllObjectsByType = IcePy.Operation('findAllObjectsByType', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (((), IcePy._t_string, False, 0),), (), ((), _M_Ice._t_ObjectProxySeq, False, 0), ())
    Query._op_findAllReplicas = IcePy.Operation('findAllReplicas', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (((), IcePy._t_ObjectPrx, False, 0),), (), ((), _M_Ice._t_ObjectProxySeq, False, 0), ())

    _M_IceGrid.Query = Query
    del Query

_M_IceGrid._t_Registry = IcePy.defineValue('::IceGrid::Registry', Ice.Value, -1, (), False, True, None, ())

if 'RegistryPrx' not in _M_IceGrid.__dict__:
    _M_IceGrid.RegistryPrx = Ice.createTempClass()
    class RegistryPrx(Ice.ObjectPrx):

        """
        Create a client session.
        Arguments:
        userId -- The user id.
        password -- The password for the given user id.
        context -- The request context for the invocation.
        Returns: A proxy for the newly created session.
        Throws:
        PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
        """
        def createSession(self, userId, password, context=None):
            return _M_IceGrid.Registry._op_createSession.invoke(self, ((userId, password), context))

        """
        Create a client session.
        Arguments:
        userId -- The user id.
        password -- The password for the given user id.
        context -- The request context for the invocation.
        Returns: A future object for the invocation.
        """
        def createSessionAsync(self, userId, password, context=None):
            return _M_IceGrid.Registry._op_createSession.invokeAsync(self, ((userId, password), context))

        """
        Create a client session.
        Arguments:
        userId -- The user id.
        password -- The password for the given user id.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        context -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_createSession(self, userId, password, _response=None, _ex=None, _sent=None, context=None):
            return _M_IceGrid.Registry._op_createSession.begin(self, ((userId, password), _response, _ex, _sent, context))

        """
        Create a client session.
        Arguments:
        userId -- The user id.
        password -- The password for the given user id.
        Returns: A proxy for the newly created session.
        Throws:
        PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
        """
        def end_createSession(self, _r):
            return _M_IceGrid.Registry._op_createSession.end(self, _r)

        """
        Create an administrative session.
        Arguments:
        userId -- The user id.
        password -- The password for the given user id.
        context -- The request context for the invocation.
        Returns: A proxy for the newly created session.
        Throws:
        PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
        """
        def createAdminSession(self, userId, password, context=None):
            return _M_IceGrid.Registry._op_createAdminSession.invoke(self, ((userId, password), context))

        """
        Create an administrative session.
        Arguments:
        userId -- The user id.
        password -- The password for the given user id.
        context -- The request context for the invocation.
        Returns: A future object for the invocation.
        """
        def createAdminSessionAsync(self, userId, password, context=None):
            return _M_IceGrid.Registry._op_createAdminSession.invokeAsync(self, ((userId, password), context))

        """
        Create an administrative session.
        Arguments:
        userId -- The user id.
        password -- The password for the given user id.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        context -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_createAdminSession(self, userId, password, _response=None, _ex=None, _sent=None, context=None):
            return _M_IceGrid.Registry._op_createAdminSession.begin(self, ((userId, password), _response, _ex, _sent, context))

        """
        Create an administrative session.
        Arguments:
        userId -- The user id.
        password -- The password for the given user id.
        Returns: A proxy for the newly created session.
        Throws:
        PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
        """
        def end_createAdminSession(self, _r):
            return _M_IceGrid.Registry._op_createAdminSession.end(self, _r)

        """
        Create a client session from a secure connection.
        Arguments:
        context -- The request context for the invocation.
        Returns: A proxy for the newly created session.
        Throws:
        PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
        """
        def createSessionFromSecureConnection(self, context=None):
            return _M_IceGrid.Registry._op_createSessionFromSecureConnection.invoke(self, ((), context))

        """
        Create a client session from a secure connection.
        Arguments:
        context -- The request context for the invocation.
        Returns: A future object for the invocation.
        """
        def createSessionFromSecureConnectionAsync(self, context=None):
            return _M_IceGrid.Registry._op_createSessionFromSecureConnection.invokeAsync(self, ((), context))

        """
        Create a client session from a secure connection.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        context -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_createSessionFromSecureConnection(self, _response=None, _ex=None, _sent=None, context=None):
            return _M_IceGrid.Registry._op_createSessionFromSecureConnection.begin(self, ((), _response, _ex, _sent, context))

        """
        Create a client session from a secure connection.
        Arguments:
        Returns: A proxy for the newly created session.
        Throws:
        PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
        """
        def end_createSessionFromSecureConnection(self, _r):
            return _M_IceGrid.Registry._op_createSessionFromSecureConnection.end(self, _r)

        """
        Create an administrative session from a secure connection.
        Arguments:
        context -- The request context for the invocation.
        Returns: A proxy for the newly created session.
        Throws:
        PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
        """
        def createAdminSessionFromSecureConnection(self, context=None):
            return _M_IceGrid.Registry._op_createAdminSessionFromSecureConnection.invoke(self, ((), context))

        """
        Create an administrative session from a secure connection.
        Arguments:
        context -- The request context for the invocation.
        Returns: A future object for the invocation.
        """
        def createAdminSessionFromSecureConnectionAsync(self, context=None):
            return _M_IceGrid.Registry._op_createAdminSessionFromSecureConnection.invokeAsync(self, ((), context))

        """
        Create an administrative session from a secure connection.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        context -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_createAdminSessionFromSecureConnection(self, _response=None, _ex=None, _sent=None, context=None):
            return _M_IceGrid.Registry._op_createAdminSessionFromSecureConnection.begin(self, ((), _response, _ex, _sent, context))

        """
        Create an administrative session from a secure connection.
        Arguments:
        Returns: A proxy for the newly created session.
        Throws:
        PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
        """
        def end_createAdminSessionFromSecureConnection(self, _r):
            return _M_IceGrid.Registry._op_createAdminSessionFromSecureConnection.end(self, _r)

        """
        Get the session timeout. If a client or administrative client
        doesn't call the session keepAlive method in the time interval
        defined by this timeout, IceGrid might reap the session.
        Arguments:
        context -- The request context for the invocation.
        Returns: The timeout (in seconds).
        """
        def getSessionTimeout(self, context=None):
            return _M_IceGrid.Registry._op_getSessionTimeout.invoke(self, ((), context))

        """
        Get the session timeout. If a client or administrative client
        doesn't call the session keepAlive method in the time interval
        defined by this timeout, IceGrid might reap the session.
        Arguments:
        context -- The request context for the invocation.
        Returns: A future object for the invocation.
        """
        def getSessionTimeoutAsync(self, context=None):
            return _M_IceGrid.Registry._op_getSessionTimeout.invokeAsync(self, ((), context))

        """
        Get the session timeout. If a client or administrative client
        doesn't call the session keepAlive method in the time interval
        defined by this timeout, IceGrid might reap the session.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        context -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getSessionTimeout(self, _response=None, _ex=None, _sent=None, context=None):
            return _M_IceGrid.Registry._op_getSessionTimeout.begin(self, ((), _response, _ex, _sent, context))

        """
        Get the session timeout. If a client or administrative client
        doesn't call the session keepAlive method in the time interval
        defined by this timeout, IceGrid might reap the session.
        Arguments:
        Returns: The timeout (in seconds).
        """
        def end_getSessionTimeout(self, _r):
            return _M_IceGrid.Registry._op_getSessionTimeout.end(self, _r)

        """
        Get the value of the ACM timeout. Clients supporting ACM
        connection heartbeats can enable them instead of explicitly
        sending keep alives requests.
        NOTE: This method is only available since Ice 3.6.
        Arguments:
        context -- The request context for the invocation.
        Returns: The timeout (in seconds).
        """
        def getACMTimeout(self, context=None):
            return _M_IceGrid.Registry._op_getACMTimeout.invoke(self, ((), context))

        """
        Get the value of the ACM timeout. Clients supporting ACM
        connection heartbeats can enable them instead of explicitly
        sending keep alives requests.
        NOTE: This method is only available since Ice 3.6.
        Arguments:
        context -- The request context for the invocation.
        Returns: A future object for the invocation.
        """
        def getACMTimeoutAsync(self, context=None):
            return _M_IceGrid.Registry._op_getACMTimeout.invokeAsync(self, ((), context))

        """
        Get the value of the ACM timeout. Clients supporting ACM
        connection heartbeats can enable them instead of explicitly
        sending keep alives requests.
        NOTE: This method is only available since Ice 3.6.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        context -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getACMTimeout(self, _response=None, _ex=None, _sent=None, context=None):
            return _M_IceGrid.Registry._op_getACMTimeout.begin(self, ((), _response, _ex, _sent, context))

        """
        Get the value of the ACM timeout. Clients supporting ACM
        connection heartbeats can enable them instead of explicitly
        sending keep alives requests.
        NOTE: This method is only available since Ice 3.6.
        Arguments:
        Returns: The timeout (in seconds).
        """
        def end_getACMTimeout(self, _r):
            return _M_IceGrid.Registry._op_getACMTimeout.end(self, _r)

        @staticmethod
        def checkedCast(proxy, facetOrContext=None, context=None):
            return _M_IceGrid.RegistryPrx.ice_checkedCast(proxy, '::IceGrid::Registry', facetOrContext, context)

        @staticmethod
        def uncheckedCast(proxy, facet=None):
            return _M_IceGrid.RegistryPrx.ice_uncheckedCast(proxy, facet)

        @staticmethod
        def ice_staticId():
            return '::IceGrid::Registry'
    _M_IceGrid._t_RegistryPrx = IcePy.defineProxy('::IceGrid::Registry', RegistryPrx)

    _M_IceGrid.RegistryPrx = RegistryPrx
    del RegistryPrx

    _M_IceGrid.Registry = Ice.createTempClass()
    class Registry(Ice.Object):

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::IceGrid::Registry')

        def ice_id(self, current=None):
            return '::IceGrid::Registry'

        @staticmethod
        def ice_staticId():
            return '::IceGrid::Registry'

        def createSession(self, userId, password, current=None):
            """
            Create a client session.
            Arguments:
            userId -- The user id.
            password -- The password for the given user id.
            current -- The Current object for the invocation.
            Returns: A future object for the invocation.
            Throws:
            PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
            """
            raise NotImplementedError("servant method 'createSession' not implemented")

        def createAdminSession(self, userId, password, current=None):
            """
            Create an administrative session.
            Arguments:
            userId -- The user id.
            password -- The password for the given user id.
            current -- The Current object for the invocation.
            Returns: A future object for the invocation.
            Throws:
            PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
            """
            raise NotImplementedError("servant method 'createAdminSession' not implemented")

        def createSessionFromSecureConnection(self, current=None):
            """
            Create a client session from a secure connection.
            Arguments:
            current -- The Current object for the invocation.
            Returns: A future object for the invocation.
            Throws:
            PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
            """
            raise NotImplementedError("servant method 'createSessionFromSecureConnection' not implemented")

        def createAdminSessionFromSecureConnection(self, current=None):
            """
            Create an administrative session from a secure connection.
            Arguments:
            current -- The Current object for the invocation.
            Returns: A future object for the invocation.
            Throws:
            PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
            """
            raise NotImplementedError("servant method 'createAdminSessionFromSecureConnection' not implemented")

        def getSessionTimeout(self, current=None):
            """
            Get the session timeout. If a client or administrative client
            doesn't call the session keepAlive method in the time interval
            defined by this timeout, IceGrid might reap the session.
            Arguments:
            current -- The Current object for the invocation.
            Returns: A future object for the invocation.
            """
            raise NotImplementedError("servant method 'getSessionTimeout' not implemented")

        def getACMTimeout(self, current=None):
            """
            Get the value of the ACM timeout. Clients supporting ACM
            connection heartbeats can enable them instead of explicitly
            sending keep alives requests.
            NOTE: This method is only available since Ice 3.6.
            Arguments:
            current -- The Current object for the invocation.
            Returns: A future object for the invocation.
            """
            raise NotImplementedError("servant method 'getACMTimeout' not implemented")

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_RegistryDisp)

        __repr__ = __str__

    _M_IceGrid._t_RegistryDisp = IcePy.defineClass('::IceGrid::Registry', Registry, (), None, ())
    Registry._ice_type = _M_IceGrid._t_RegistryDisp

    Registry._op_createSession = IcePy.Operation('createSession', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_string, False, 0)), (), ((), _M_IceGrid._t_SessionPrx, False, 0), (_M_IceGrid._t_PermissionDeniedException,))
    Registry._op_createAdminSession = IcePy.Operation('createAdminSession', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_string, False, 0)), (), ((), _M_IceGrid._t_AdminSessionPrx, False, 0), (_M_IceGrid._t_PermissionDeniedException,))
    Registry._op_createSessionFromSecureConnection = IcePy.Operation('createSessionFromSecureConnection', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_IceGrid._t_SessionPrx, False, 0), (_M_IceGrid._t_PermissionDeniedException,))
    Registry._op_createAdminSessionFromSecureConnection = IcePy.Operation('createAdminSessionFromSecureConnection', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_IceGrid._t_AdminSessionPrx, False, 0), (_M_IceGrid._t_PermissionDeniedException,))
    Registry._op_getSessionTimeout = IcePy.Operation('getSessionTimeout', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Registry._op_getACMTimeout = IcePy.Operation('getACMTimeout', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())

    _M_IceGrid.Registry = Registry
    del Registry

_M_IceGrid._t_Locator = IcePy.defineValue('::IceGrid::Locator', Ice.Value, -1, (), False, True, None, ())

if 'LocatorPrx' not in _M_IceGrid.__dict__:
    _M_IceGrid.LocatorPrx = Ice.createTempClass()
    class LocatorPrx(_M_Ice.LocatorPrx):

        """
        Get the proxy of the registry object hosted by this IceGrid
        registry.
        Arguments:
        context -- The request context for the invocation.
        Returns: The proxy of the registry object.
        """
        def getLocalRegistry(self, context=None):
            return _M_IceGrid.Locator._op_getLocalRegistry.invoke(self, ((), context))

        """
        Get the proxy of the registry object hosted by this IceGrid
        registry.
        Arguments:
        context -- The request context for the invocation.
        Returns: A future object for the invocation.
        """
        def getLocalRegistryAsync(self, context=None):
            return _M_IceGrid.Locator._op_getLocalRegistry.invokeAsync(self, ((), context))

        """
        Get the proxy of the registry object hosted by this IceGrid
        registry.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        context -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getLocalRegistry(self, _response=None, _ex=None, _sent=None, context=None):
            return _M_IceGrid.Locator._op_getLocalRegistry.begin(self, ((), _response, _ex, _sent, context))

        """
        Get the proxy of the registry object hosted by this IceGrid
        registry.
        Arguments:
        Returns: The proxy of the registry object.
        """
        def end_getLocalRegistry(self, _r):
            return _M_IceGrid.Locator._op_getLocalRegistry.end(self, _r)

        """
        Get the proxy of the query object hosted by this IceGrid
        registry.
        Arguments:
        context -- The request context for the invocation.
        Returns: The proxy of the query object.
        """
        def getLocalQuery(self, context=None):
            return _M_IceGrid.Locator._op_getLocalQuery.invoke(self, ((), context))

        """
        Get the proxy of the query object hosted by this IceGrid
        registry.
        Arguments:
        context -- The request context for the invocation.
        Returns: A future object for the invocation.
        """
        def getLocalQueryAsync(self, context=None):
            return _M_IceGrid.Locator._op_getLocalQuery.invokeAsync(self, ((), context))

        """
        Get the proxy of the query object hosted by this IceGrid
        registry.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        context -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getLocalQuery(self, _response=None, _ex=None, _sent=None, context=None):
            return _M_IceGrid.Locator._op_getLocalQuery.begin(self, ((), _response, _ex, _sent, context))

        """
        Get the proxy of the query object hosted by this IceGrid
        registry.
        Arguments:
        Returns: The proxy of the query object.
        """
        def end_getLocalQuery(self, _r):
            return _M_IceGrid.Locator._op_getLocalQuery.end(self, _r)

        @staticmethod
        def checkedCast(proxy, facetOrContext=None, context=None):
            return _M_IceGrid.LocatorPrx.ice_checkedCast(proxy, '::IceGrid::Locator', facetOrContext, context)

        @staticmethod
        def uncheckedCast(proxy, facet=None):
            return _M_IceGrid.LocatorPrx.ice_uncheckedCast(proxy, facet)

        @staticmethod
        def ice_staticId():
            return '::IceGrid::Locator'
    _M_IceGrid._t_LocatorPrx = IcePy.defineProxy('::IceGrid::Locator', LocatorPrx)

    _M_IceGrid.LocatorPrx = LocatorPrx
    del LocatorPrx

    _M_IceGrid.Locator = Ice.createTempClass()
    class Locator(_M_Ice.Locator):

        def ice_ids(self, current=None):
            return ('::Ice::Locator', '::Ice::Object', '::IceGrid::Locator')

        def ice_id(self, current=None):
            return '::IceGrid::Locator'

        @staticmethod
        def ice_staticId():
            return '::IceGrid::Locator'

        def getLocalRegistry(self, current=None):
            """
            Get the proxy of the registry object hosted by this IceGrid
            registry.
            Arguments:
            current -- The Current object for the invocation.
            Returns: A future object for the invocation.
            """
            raise NotImplementedError("servant method 'getLocalRegistry' not implemented")

        def getLocalQuery(self, current=None):
            """
            Get the proxy of the query object hosted by this IceGrid
            registry.
            Arguments:
            current -- The Current object for the invocation.
            Returns: A future object for the invocation.
            """
            raise NotImplementedError("servant method 'getLocalQuery' not implemented")

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_LocatorDisp)

        __repr__ = __str__

    _M_IceGrid._t_LocatorDisp = IcePy.defineClass('::IceGrid::Locator', Locator, (), None, (_M_Ice._t_LocatorDisp,))
    Locator._ice_type = _M_IceGrid._t_LocatorDisp

    Locator._op_getLocalRegistry = IcePy.Operation('getLocalRegistry', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (), (), ((), _M_IceGrid._t_RegistryPrx, False, 0), ())
    Locator._op_getLocalQuery = IcePy.Operation('getLocalQuery', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (), (), ((), _M_IceGrid._t_QueryPrx, False, 0), ())

    _M_IceGrid.Locator = Locator
    del Locator

# End of module IceGrid

Ice.sliceChecksums["::IceGrid::LoadSample"] = "ec48c06fa099138a5fbbce121a9a290"
Ice.sliceChecksums["::IceGrid::Locator"] = "816e9d7a3cb39b8c80fe342e7f18ae"
Ice.sliceChecksums["::IceGrid::Query"] = "39dbe5f62c19aa42c2e0fbaf220b4f1"
Ice.sliceChecksums["::IceGrid::Registry"] = "8298cc0aba1a722d75eb79034fbb076"



# -*- coding: utf-8 -*-
#
# Copyright (c) ZeroC, Inc. All rights reserved.
#
#
# Ice version 3.7.8
#
# <auto-generated>
#
# Generated from file `UserAccountMapper.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy

# Start of module IceGrid
_M_IceGrid = Ice.openModule('IceGrid')
__name__ = 'IceGrid'

if 'UserAccountNotFoundException' not in _M_IceGrid.__dict__:
    _M_IceGrid.UserAccountNotFoundException = Ice.createTempClass()
    class UserAccountNotFoundException(Ice.UserException):
        """
        This exception is raised if a user account for a given session
        identifier can't be found.
        """
        def __init__(self):
            pass

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_id = '::IceGrid::UserAccountNotFoundException'

    _M_IceGrid._t_UserAccountNotFoundException = IcePy.defineException('::IceGrid::UserAccountNotFoundException', UserAccountNotFoundException, (), False, None, ())
    UserAccountNotFoundException._ice_type = _M_IceGrid._t_UserAccountNotFoundException

    _M_IceGrid.UserAccountNotFoundException = UserAccountNotFoundException
    del UserAccountNotFoundException

_M_IceGrid._t_UserAccountMapper = IcePy.defineValue('::IceGrid::UserAccountMapper', Ice.Value, -1, (), False, True, None, ())

if 'UserAccountMapperPrx' not in _M_IceGrid.__dict__:
    _M_IceGrid.UserAccountMapperPrx = Ice.createTempClass()
    class UserAccountMapperPrx(Ice.ObjectPrx):

        """
        Get the name of the user account for the given user. This is
        used by IceGrid nodes to figure out the user account to use
        to run servers.
        Arguments:
        user -- The value of the server descriptor's user attribute. If this attribute is not defined, and the server's activation mode is session, the default value of user is the session identifier.
        context -- The request context for the invocation.
        Returns: The user account name.
        Throws:
        UserAccountNotFoundException -- Raised if no user account is found for the given user.
        """
        def getUserAccount(self, user, context=None):
            return _M_IceGrid.UserAccountMapper._op_getUserAccount.invoke(self, ((user, ), context))

        """
        Get the name of the user account for the given user. This is
        used by IceGrid nodes to figure out the user account to use
        to run servers.
        Arguments:
        user -- The value of the server descriptor's user attribute. If this attribute is not defined, and the server's activation mode is session, the default value of user is the session identifier.
        context -- The request context for the invocation.
        Returns: A future object for the invocation.
        """
        def getUserAccountAsync(self, user, context=None):
            return _M_IceGrid.UserAccountMapper._op_getUserAccount.invokeAsync(self, ((user, ), context))

        """
        Get the name of the user account for the given user. This is
        used by IceGrid nodes to figure out the user account to use
        to run servers.
        Arguments:
        user -- The value of the server descriptor's user attribute. If this attribute is not defined, and the server's activation mode is session, the default value of user is the session identifier.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        context -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getUserAccount(self, user, _response=None, _ex=None, _sent=None, context=None):
            return _M_IceGrid.UserAccountMapper._op_getUserAccount.begin(self, ((user, ), _response, _ex, _sent, context))

        """
        Get the name of the user account for the given user. This is
        used by IceGrid nodes to figure out the user account to use
        to run servers.
        Arguments:
        user -- The value of the server descriptor's user attribute. If this attribute is not defined, and the server's activation mode is session, the default value of user is the session identifier.
        Returns: The user account name.
        Throws:
        UserAccountNotFoundException -- Raised if no user account is found for the given user.
        """
        def end_getUserAccount(self, _r):
            return _M_IceGrid.UserAccountMapper._op_getUserAccount.end(self, _r)

        @staticmethod
        def checkedCast(proxy, facetOrContext=None, context=None):
            return _M_IceGrid.UserAccountMapperPrx.ice_checkedCast(proxy, '::IceGrid::UserAccountMapper', facetOrContext, context)

        @staticmethod
        def uncheckedCast(proxy, facet=None):
            return _M_IceGrid.UserAccountMapperPrx.ice_uncheckedCast(proxy, facet)

        @staticmethod
        def ice_staticId():
            return '::IceGrid::UserAccountMapper'
    _M_IceGrid._t_UserAccountMapperPrx = IcePy.defineProxy('::IceGrid::UserAccountMapper', UserAccountMapperPrx)

    _M_IceGrid.UserAccountMapperPrx = UserAccountMapperPrx
    del UserAccountMapperPrx

    _M_IceGrid.UserAccountMapper = Ice.createTempClass()
    class UserAccountMapper(Ice.Object):

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::IceGrid::UserAccountMapper')

        def ice_id(self, current=None):
            return '::IceGrid::UserAccountMapper'

        @staticmethod
        def ice_staticId():
            return '::IceGrid::UserAccountMapper'

        def getUserAccount(self, user, current=None):
            """
            Get the name of the user account for the given user. This is
            used by IceGrid nodes to figure out the user account to use
            to run servers.
            Arguments:
            user -- The value of the server descriptor's user attribute. If this attribute is not defined, and the server's activation mode is session, the default value of user is the session identifier.
            current -- The Current object for the invocation.
            Returns: A future object for the invocation.
            Throws:
            UserAccountNotFoundException -- Raised if no user account is found for the given user.
            """
            raise NotImplementedError("servant method 'getUserAccount' not implemented")

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_UserAccountMapperDisp)

        __repr__ = __str__

    _M_IceGrid._t_UserAccountMapperDisp = IcePy.defineClass('::IceGrid::UserAccountMapper', UserAccountMapper, (), None, ())
    UserAccountMapper._ice_type = _M_IceGrid._t_UserAccountMapperDisp

    UserAccountMapper._op_getUserAccount = IcePy.Operation('getUserAccount', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_string, False, 0),), (), ((), IcePy._t_string, False, 0), (_M_IceGrid._t_UserAccountNotFoundException,))

    _M_IceGrid.UserAccountMapper = UserAccountMapper
    del UserAccountMapper

# End of module IceGrid

Ice.sliceChecksums["::IceGrid::UserAccountMapper"] = "779fd561878e199444e04cdebaf9ffd4"
Ice.sliceChecksums["::IceGrid::UserAccountNotFoundException"] = "fe2dc4d87f21b9b2cf6f1339d1666281"



# -*- coding: utf-8 -*-
#
# Copyright (c) ZeroC, Inc. All rights reserved.
#
#
# Ice version 3.7.8
#
# <auto-generated>
#
# Generated from file `PluginFacade.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import Ice.BuiltinSequences_ice
import Ice.Current_ice
import IceGrid.Admin_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Included module IceGrid
_M_IceGrid = Ice.openModule('IceGrid')

# Start of module IceGrid
__name__ = 'IceGrid'

if 'ReplicaGroupFilter' not in _M_IceGrid.__dict__:
    _M_IceGrid.ReplicaGroupFilter = Ice.createTempClass()
    class ReplicaGroupFilter(object):
        """
        The ReplicaGroupFilter is used by IceGrid to filter adapters
        returned to the client when it resolves a filtered replica group.
        IceGrid provides the list of available adapters. The implementation
        of this method can use the provided context and connection to
        filter and return the filtered set of adapters.
        """
        def __init__(self):
            if Ice.getType(self) == _M_IceGrid.ReplicaGroupFilter:
                raise RuntimeError('IceGrid.ReplicaGroupFilter is an abstract class')

        def filter(self, replicaGroupId, adapterIds, con, ctx):
            """
            Filter the the given set of adapters.
            Arguments:
            replicaGroupId -- The replica group ID.
            adapterIds -- The adpater IDs to filter.
            con -- The connection from the Ice client which is resolving the replica group endpoints.
            ctx -- The context from the Ice client which is resolving the replica group endpoints.
            Returns: The filtered adapter IDs.
            """
            raise NotImplementedError("method 'filter' not implemented")

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_ReplicaGroupFilter)

        __repr__ = __str__

    _M_IceGrid._t_ReplicaGroupFilter = IcePy.defineValue('::IceGrid::ReplicaGroupFilter', ReplicaGroupFilter, -1, (), False, True, None, ())
    ReplicaGroupFilter._ice_type = _M_IceGrid._t_ReplicaGroupFilter

    _M_IceGrid.ReplicaGroupFilter = ReplicaGroupFilter
    del ReplicaGroupFilter

if 'TypeFilter' not in _M_IceGrid.__dict__:
    _M_IceGrid.TypeFilter = Ice.createTempClass()
    class TypeFilter(object):
        """
        The TypeFilter is used by IceGrid to filter well-known proxies
        returned to the client when it searches a well-known object by
        type.
        IceGrid provides the list of available proxies. The implementation
        of this method can use the provided context and connection to
        filter and return the filtered set of proxies.
        """
        def __init__(self):
            if Ice.getType(self) == _M_IceGrid.TypeFilter:
                raise RuntimeError('IceGrid.TypeFilter is an abstract class')

        def filter(self, type, proxies, con, ctx):
            """
            Filter the the given set of proxies.
            Arguments:
            type -- The type.
            proxies -- The proxies to filter.
            con -- The connection from the Ice client which is looking up well-known objects by type.
            ctx -- The context from the Ice client which is looking up well-known objects by type.
            Returns: The filtered proxies.
            """
            raise NotImplementedError("method 'filter' not implemented")

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_TypeFilter)

        __repr__ = __str__

    _M_IceGrid._t_TypeFilter = IcePy.defineValue('::IceGrid::TypeFilter', TypeFilter, -1, (), False, True, None, ())
    TypeFilter._ice_type = _M_IceGrid._t_TypeFilter

    _M_IceGrid.TypeFilter = TypeFilter
    del TypeFilter

if 'RegistryPluginFacade' not in _M_IceGrid.__dict__:
    _M_IceGrid.RegistryPluginFacade = Ice.createTempClass()
    class RegistryPluginFacade(object):
        """
        The RegistryPluginFacade is implemented by IceGrid and can be used
        by plugins and filter implementations to retrieve information from
        IceGrid about the well-known objects or adapters. It's also used to
        register/unregister replica group and type filters.
        """
        def __init__(self):
            if Ice.getType(self) == _M_IceGrid.RegistryPluginFacade:
                raise RuntimeError('IceGrid.RegistryPluginFacade is an abstract class')

        def getApplicationInfo(self, name):
            """
            Get an application descriptor.
            Arguments:
            name -- The application name.
            Returns: The application descriptor.
            Throws:
            ApplicationNotExistException -- Raised if the application doesn't exist.
            """
            raise NotImplementedError("method 'getApplicationInfo' not implemented")

        def getServerInfo(self, id):
            """
            Get the server information for the server with the given id.
            Arguments:
            id -- The server id.
            Returns: The server information.
            Throws:
            ServerNotExistException -- Raised if the server doesn't exist.
            """
            raise NotImplementedError("method 'getServerInfo' not implemented")

        def getAdapterServer(self, adapterId):
            """
            Get the ID of the server to which the given adapter belongs.
            Arguments:
            adapterId -- The adapter ID.
            Returns: The server ID or the empty string if the given identifier is not associated to an object adapter defined with an application descriptor.
            Throws:
            AdapterNotExistException -- Raised if the adapter doesn't exist.
            """
            raise NotImplementedError("method 'getAdapterServer' not implemented")

        def getAdapterApplication(self, adapterId):
            """
            Get the name of the application to which the given adapter belongs.
            Arguments:
            adapterId -- The adapter ID.
            Returns: The application name or the empty string if the given identifier is not associated to a replica group or object adapter defined with an application descriptor.
            Throws:
            AdapterNotExistException -- Raised if the adapter doesn't exist.
            """
            raise NotImplementedError("method 'getAdapterApplication' not implemented")

        def getAdapterNode(self, adapterId):
            """
            Get the name of the node to which the given adapter belongs.
            Arguments:
            adapterId -- The adapter ID.
            Returns: The node name or the empty string if the given identifier is not associated to an object adapter defined with an application descriptor.
            Throws:
            AdapterNotExistException -- Raised if the adapter doesn't exist.
            """
            raise NotImplementedError("method 'getAdapterNode' not implemented")

        def getAdapterInfo(self, id):
            """
            Get the adapter information for the replica group or adapter
            with the given id.
            Arguments:
            id -- The adapter id.
            Returns: A sequence of adapter information structures. If the given id refers to an adapter, this sequence will contain only one element. If the given id refers to a replica group, the sequence will contain the adapter information of each member of the replica group.
            Throws:
            AdapterNotExistException -- Raised if the adapter or replica group doesn't exist.
            """
            raise NotImplementedError("method 'getAdapterInfo' not implemented")

        def getObjectInfo(self, id):
            """
            Get the object info for the object with the given identity.
            Arguments:
            id -- The identity of the object.
            Returns: The object info.
            Throws:
            ObjectNotRegisteredException -- Raised if the object isn't registered with the registry.
            """
            raise NotImplementedError("method 'getObjectInfo' not implemented")

        def getNodeInfo(self, name):
            """
            Get the node information for the node with the given name.
            Arguments:
            name -- The node name.
            Returns: The node information.
            Throws:
            NodeNotExistException -- Raised if the node doesn't exist.
            NodeUnreachableException -- Raised if the node could not be reached.
            """
            raise NotImplementedError("method 'getNodeInfo' not implemented")

        def getNodeLoad(self, name):
            """
            Get the load averages of the node.
            Arguments:
            name -- The node name.
            Returns: The node load information.
            Throws:
            NodeNotExistException -- Raised if the node doesn't exist.
            NodeUnreachableException -- Raised if the node could not be reached.
            """
            raise NotImplementedError("method 'getNodeLoad' not implemented")

        def getPropertyForAdapter(self, adapterId, name):
            """
            Get the property value for the given property and adapter. The
            property is looked up in the server or service descriptor where
            the adapter is defined.
            Arguments:
            adapterId -- The adapter ID
            name -- The name of the property.
            Returns: The property value.
            Throws:
            AdapterNotExistException -- Raised if the adapter doesn't exist.
            """
            raise NotImplementedError("method 'getPropertyForAdapter' not implemented")

        def addReplicaGroupFilter(self, id, filter):
            """
            Add a replica group filter.
            Arguments:
            id -- The identifier of the filter. This identifier must match the value of the "filter" attribute specified in the replica group descriptor. To filter dynamically registered replica groups, you should use the empty filter id.
            filter -- The filter implementation.
            """
            raise NotImplementedError("method 'addReplicaGroupFilter' not implemented")

        def removeReplicaGroupFilter(self, id, filter):
            """
            Remove a replica group filter.
            Arguments:
            id -- The identifier of the filter.
            filter -- The filter implementation.
            Returns: True of the filter was removed, false otherwise.
            """
            raise NotImplementedError("method 'removeReplicaGroupFilter' not implemented")

        def addTypeFilter(self, type, filter):
            """
            Add a type filter.
            Arguments:
            type -- The type to register this filter with.
            filter -- The filter implementation.
            """
            raise NotImplementedError("method 'addTypeFilter' not implemented")

        def removeTypeFilter(self, type, filter):
            """
            Remove a type filter.
            Arguments:
            type -- The type to register this filter with.
            filter -- The filter implementation.
            Returns: True of the filter was removed, false otherwise.
            """
            raise NotImplementedError("method 'removeTypeFilter' not implemented")

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_RegistryPluginFacade)

        __repr__ = __str__

    _M_IceGrid._t_RegistryPluginFacade = IcePy.defineValue('::IceGrid::RegistryPluginFacade', RegistryPluginFacade, -1, (), False, True, None, ())
    RegistryPluginFacade._ice_type = _M_IceGrid._t_RegistryPluginFacade

    _M_IceGrid.RegistryPluginFacade = RegistryPluginFacade
    del RegistryPluginFacade

# End of module IceGrid



# -*- coding: utf-8 -*-
#
# Copyright (c) ZeroC, Inc. All rights reserved.
#
#
# Ice version 3.7.8
#
# <auto-generated>
#
# Generated from file `RouterF.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy

# Start of module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')
__name__ = 'Glacier2'

if 'Router' not in _M_Glacier2.__dict__:
    _M_Glacier2._t_RouterDisp = IcePy.declareClass('::Glacier2::Router')
    _M_Glacier2._t_RouterPrx = IcePy.declareProxy('::Glacier2::Router')

# End of module Glacier2
